/*	Floor Lamp v1.03
//	Author : GeeknessFr
//  Original Release Date : 03-16-2018
//  Updated : 03-18-2018
*/

namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared.Math;
    using Eco.Shared.Serialization;

    [Serialized]
    [RequireComponent(typeof(OnOffComponent))]
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]
    [RequireComponent(typeof(PowerGridComponent))]
    [RequireComponent(typeof(PowerConsumptionComponent))]
    [RequireComponent(typeof(HousingComponent))]
    public partial class FloorLampObject : WorldObject
    {
        public override string FriendlyName { get { return "Floor Lamp v2"; } }

        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Lights");
            this.GetComponent<PowerConsumptionComponent>().Initialize(40);
            this.GetComponent<PowerGridComponent>().Initialize(10, new ElectricPower());
            this.GetComponent<HousingComponent>().Set(FloorLampItem.HousingVal);
        }

        static FloorLampObject()
        {
            AddOccupancy<FloorLampObject>(new List<BlockOccupancy>(){
                new BlockOccupancy(new Vector3i(0, 0, 0), typeof(BuildingWorldObjectBlock), new Quaternion(0f, 0f, 0f, 1f)),
            });
        }

        public override void Destroy()
        {
            base.Destroy();
        }

        public override void Tick()
        {
            base.Tick();
            SetAnimatedState("Fade", this.Operating);
        }
    }

    [Serialized]
    public partial class FloorLampItem : WorldObjectItem<FloorLampObject>
    {
        public override string FriendlyName { get { return "Floor Lamp v2"; } }
        public override string Description { get { return "A Floor Lamp to Light your Feet !"; } }

        static FloorLampItem()
        {

        }

        [TooltipChildren] public HousingValue HousingTooltip { get { return HousingVal; } }
        [TooltipChildren]
        public static HousingValue HousingVal
        {
            get
            {
                return new HousingValue()
                {
                    Category = "General",
                    Val = 2,
                    TypeForRoomLimit = "Lights",
                    DiminishingReturnPercent = 0.90f
                };
            }
        }
    }


    [RequiresSkill(typeof(ElectronicEngineeringSkill), 3)]
    public partial class FloorLampRecipe : Recipe
    {
        public FloorLampRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<FloorLampItem>(),
            };

            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<SteelItem>(typeof(ElectronicEngineeringEfficiencySkill), 8, ElectronicEngineeringEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(1, ElectronicEngineeringSpeedSkill.MultiplicativeStrategy, typeof(ElectronicEngineeringSpeedSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(FloorLampRecipe), Item.Get<FloorLampItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<FloorLampItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize("Floor Lamp v2", typeof(FloorLampRecipe));
            CraftingComponent.AddRecipe(typeof(FactoryObject), this);
        }
    }
}